Crate defund_cosmwasm

Crate defund_cosmwasm 

Structs

Balances
BaseDenom
Broker
DefundQuerier
This is a helper wrapper to easily use our custom queries
DefundQueryWrapper
SeiQueryWrapper is an override of QueryRequest::Custom to access Sei-specific modules
Fund
GetBrokerResponse
GetBrokerResponse is data format returned from GetBroker query
GetBrokersResponse
GetBrokersResponse is data format returned from GetBrokers query
GetFundPriceResponse
GetFundPriceResponse is data format returned from GetFundPrice query
GetFundResponse
GetFundResponse is data format returned from GetFund query
GetFundsResponse
GetFundsResponse is data format returned from GetFunds query
Holding
PageRequest
Enums

DefundMsg
DefundMsg is an override of CosmosMsg::Custom to add support for Defund’s custom message types
DefundQuery
DefundQuery is an override of QueryRequest::Custom to access Defund-specific modules
DefundRoute
DefundRoute is the module path route for the query
FundType