pub enum DefundQuery {
GetFund {
symbol: String,
},
GetFunds {
pagination: PageRequest,
},
GetFundPrice {
symbol: String,
},
GetBroker {
broker: String,
},
GetBrokers {
pagination: PageRequest,
},
}Expand description
DefundQuery is an override of QueryRequest::Custom to access Defund-specific modules
Variants
GetFund
GetFunds
Fields

pagination: PageRequestGetFundPrice
GetBroker
GetBrokers
Fields

pagination: PageRequestTrait Implementations
Sourceimpl Clone for DefundQuery
impl Clone for DefundQuery
Sourcefn clone(&self) -> DefundQuery
fn clone(&self) -> DefundQuery
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DefundQuery
impl Debug for DefundQuery
Sourceimpl<'de> Deserialize<'de> for DefundQuery
impl<'de> Deserialize<'de> for DefundQuery
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DefundQuery
impl JsonSchema for DefundQuery
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DefundQuery
impl PartialEq for DefundQuery
Sourceimpl Serialize for DefundQuery
impl Serialize for DefundQuery
impl StructuralPartialEq for DefundQuery