pub struct DefundQueryWrapper {
pub route: DefundRoute,
pub query_data: DefundQuery,
}Expand description
SeiQueryWrapper is an override of QueryRequest::Custom to access Sei-specific modules
Fields
route: DefundRoutequery_data: DefundQueryTrait Implementations
Sourceimpl Clone for DefundQueryWrapper
impl Clone for DefundQueryWrapper
Sourcefn clone(&self) -> DefundQueryWrapper
fn clone(&self) -> DefundQueryWrapper
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DefundQueryWrapper
impl Debug for DefundQueryWrapper
Sourceimpl<'de> Deserialize<'de> for DefundQueryWrapper
impl<'de> Deserialize<'de> for DefundQueryWrapper
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DefundQueryWrapper
impl JsonSchema for DefundQueryWrapper
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DefundQueryWrapper
impl PartialEq for DefundQueryWrapper
Sourceimpl Serialize for DefundQueryWrapper
impl Serialize for DefundQueryWrapper
impl CustomQuery for DefundQueryWrapper
impl StructuralPartialEq for DefundQueryWrapper